/*
 * voicechat-sm111.sp
 * Copyright (c) 2021, 2022 Ed <https://d-rine.com/~ed/>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

#include <sourcemod>
#include <sdktools>

public Plugin myinfo =
{
	name = "Voice Chat List (SourceMod v1.11 Version)",
	author = "EDSHOT",
	description = "Print to the center of the screen a list of players who are talking",
	version = "0.4"
};

Handle g_Cvar_AllTalk;
bool TeamAll[32+1] = false;
bool TeamSurvivor[32+1] = false;
bool TeamInfected[32+1] = false;
bool TeamSpectator[32+1] = false;
char buf[4096];
char buf2[128];

public void OnPluginStart()
{
	g_Cvar_AllTalk = FindConVar("sv_alltalk");
	LoadTranslations("voicechat.phrases");
}

public void OnPluginEnd()
{
	CloseHandle(g_Cvar_AllTalk);
}

public void OnClientSpeakingEnd(int client)
{
	if (client == 0 || !IsClientConnected(client) || !IsClientInGame(client) || IsFakeClient(client)) return;

	TeamAll[client] = false;
	TeamSurvivor[client] = false;
	TeamInfected[client] = false;
	TeamSpectator[client] = false;
}

public void OnClientSpeaking(int client)
{
	if (client == 0 || !IsClientConnected(client) || !IsClientInGame(client) || IsFakeClient(client)) return;

	if (GetConVarInt(g_Cvar_AllTalk) == 1) TeamAll[client] = true;
	if (GetConVarInt(g_Cvar_AllTalk) == 0 && GetClientTeam(client) == 1) TeamSpectator[client] = true;
	if (GetConVarInt(g_Cvar_AllTalk) == 0 && GetClientTeam(client) == 2) TeamSurvivor[client] = true;
	if (GetConVarInt(g_Cvar_AllTalk) == 0 && GetClientTeam(client) == 3) TeamInfected[client] = true;

	for (int p = 1; p <= GetMaxClients(); p++)
	{
		if (IsClientInGame(p) && !IsFakeClient(p) && GetConVarInt(g_Cvar_AllTalk) == 1)
		{
			Format(buf, sizeof(buf), "%T (%T):\n", "Voice Chat List", p, "All Teams", p);
			for (int p2 = 1; p2 <= GetMaxClients(); p2++)
			{
				if (TeamAll[p2])
				{
					Format(buf2, sizeof(buf2), "%N\n", p2);
					StrCat(buf, sizeof(buf), buf2);
				}
			}
			PrintCenterText(p, buf);
		}

		if (IsClientInGame(p) && !IsFakeClient(p) && GetConVarInt(g_Cvar_AllTalk) == 0 && GetClientTeam(p) == 1)
		{
			Format(buf, sizeof(buf), "%T (%T):\n", "Voice Chat List", p, "Spectators", p);
			for (int p2 = 1; p2 <= GetMaxClients(); p2++)
			{
				if (TeamSpectator[p2])
				{
					Format(buf2, sizeof(buf2), "%N\n", p2);
					StrCat(buf, sizeof(buf), buf2);
				}
			}
			PrintCenterText(p, buf);
		}

		if (IsClientInGame(p) && !IsFakeClient(p) && GetConVarInt(g_Cvar_AllTalk) == 0 && GetClientTeam(p) == 2)
		{
			Format(buf, sizeof(buf), "%T (%T):\n", "Voice Chat List", p, "Survivors", p);
			for (int p2 = 1; p2 <= GetMaxClients(); p2++)
			{
				if (TeamSurvivor[p2])
				{
					Format(buf2, sizeof(buf2), "%N\n", p2);
					StrCat(buf, sizeof(buf), buf2);
				}
			}
			PrintCenterText(p, buf);
		}

		if (IsClientInGame(p) && !IsFakeClient(p) && GetConVarInt(g_Cvar_AllTalk) == 0 && GetClientTeam(p) == 3)
		{
			Format(buf, sizeof(buf), "%T (%T):\n", "Voice Chat List", p, "Infected", p);
			for (int p2 = 1; p2 <= GetMaxClients(); p2++)
			{
				if (TeamInfected[p2])
				{
					Format(buf2, sizeof(buf2), "%N\n", p2);
					StrCat(buf, sizeof(buf), buf2);
				}
			}
			PrintCenterText(p, buf);
		}
	}
}
